@@ -37,11 +37,13 @@ from psyplot.plotter import unique_everseen, Plotter
 from psyplot.compat.pycompat import (OrderedDict, range, getcwd,
                                      get_default_value as _get_default_value)
 try:
-    from cdo import Cdo as _CdoBase
+    from cdo import Cdo as _CdoBase, CDO_PY_VERSION as cdo_version
     with_cdo = True
+    cdo_version = tuple(map(int, cdo_version.split('.')[:2]))
 except ImportError as e:
     Cdo = _MissingModule(e)
     with_cdo = False
+    cdo_version = None
 
 try:  # try import show_colormaps for convenience
     from psy_simple.colors import show_colormaps, get_cmap
@@ -2203,19 +2205,24 @@ if with_cdo:
             """)
 
         def __init__(self, *args, **kwargs):
-            kwargs.setdefault('cdfMod', CDF_MOD_NCREADER)
+            if cdo_version < (1, 5):
+                kwargs.setdefault('cdfMod', CDF_MOD_NCREADER)
             super(Cdo, self).__init__(*args, **kwargs)
-            self.loadCdf()
+            if cdo_version < (1, 5):
+                self.loadCdf()
 
         def loadCdf(self, *args, **kwargs):
             """Load data handler as specified by self.cdfMod"""
-            def open_nc(*args, **kwargs):
-                kwargs.pop('mode', None)
-                return open_dataset(*args, **kwargs)
-            if self.cdfMod == CDF_MOD_NCREADER:
-                self.cdf = open_nc
+            if cdo_version < (1, 5):
+                def open_nc(*args, **kwargs):
+                    kwargs.pop('mode', None)
+                    return open_dataset(*args, **kwargs)
+                if self.cdfMod == CDF_MOD_NCREADER:
+                    self.cdf = open_nc
+                else:
+                    super(Cdo, self).loadCdf(*args, **kwargs)
             else:
-                super(Cdo, self).loadCdf(*args, **kwargs)
+                super(Cdo, self).readCdf(*args, **kwargs)
 
         def __getattr__(self, method_name):
             def my_get(get):
@@ -2232,7 +2239,10 @@ if with_cdo:
                         dims = kwargs.pop('dims', {})
                         name = kwargs.pop('name', None)
                         method = kwargs.pop('method', 'isel')
-                        kwargs['returnCdf'] = True
+                        if cdo_version < (1, 5):
+                            kwargs['returnCdf'] = True
+                        else:
+                            kwargs['returnXDataset'] = True
                         ds = get(*args, **kwargs)
                         if isinstance(plot_method, six.string_types):
                             plot_method = getattr(plot, plot_method)
@@ -2248,14 +2258,10 @@ if with_cdo:
                     else:
                         return get(*args, **kwargs)
                 return wrapper
-            if method_name == 'cdf':
-                # initialize cdf module implicitly
-                self.loadCdf()
-                return self.cdf
-            else:
-                get = my_get(super(Cdo, self).__getattr__(method_name))
-                setattr(self.__class__, method_name, get)
-                return get.__get__(self)
+
+            get = my_get(super(Cdo, self).__getattr__(method_name))
+            setattr(self.__class__, method_name, get)
+            return get.__get__(self)
 
 
 @dedent
